@@ -5,7 +5,6 @@
 # Created: 2021/11/17, Updated: 2022/02/15
 # Written by Maximilian Felix Caspar, DESY HH
 
-
 from loguru import logger
 import argh
 import json
@@ -29,8 +28,13 @@ def register(excelFile: "Excel file containing the component data",
              sheetName: "Name or number of the excel sheet to process" = 0
              ):
     "Registering components from an excel file."
-    df = pd.read_excel(excelFile, header=1, sheet_name=sheetName)
+    if isinstance(excelFile,str):
+        df = pd.read_excel(excelFile, header=1, sheet_name=sheetName)
+    elif isinstance(excelFile, pd.DataFrame):
+        df = excelFile
+    else: print('Your excelFile was of bad type: ', type(excelFile))
     print(df)
+    # If a transformation Function is given, this will be used
     if lambdaFunction is not None:
         df = lambdaFunction(df)
         logger.info("Modified the dataframe")
@@ -87,14 +91,14 @@ def ship(value: "Values to look up (can be a list)" = None,
          generatePDFs: "Generate PDFs from the docx files (requires Windows + a Word installation)" = False
          ):
     "Ship items to another institution and generate packaging slips."
-
+    print('Starting to prepare ~~~')
     def getDate(component):
         "Helper function to get the manufacturing date from a DB object."
         properties = component["properties"]
         for p in properties:
             if p["code"] == "MANUFACTURING_DATE":
                 return p["value"]
-        return None
+        return '-'
     print(value)
 
     if value is None:
