@@ -5,6 +5,10 @@
 # Created: 2021/11/17, Updated: 2022/01/24
 # Written by Maximilian Felix Caspar, DESY HH
 
+import sys
+
+import didis.didis as dd
+import didis.batch as ddb
 
 from loguru import logger
 import argh
@@ -41,6 +45,7 @@ def lookup(project: "ATLAS Project" = 'S',
            returnResults: "Return lookup results (useful if not used from CLI)" = False,
            printJSON: "PrettyPrint the component JSON" = False):
     "Look up a component or list of components in the DB."
+
     try:
         if value is None:
             value = []
@@ -157,14 +162,35 @@ def tests(componentType: "Type of component" = "BT",
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
 
-def stage(lookupValue: "Value to look up (must be unique in the DB!)",
+def get_stage(lookupValue: "Value to look up (must be unique in the DB!)",
+              project: "ATLAS Subproject" = 'S',
+              lookupKey: "Key that corresponds to VALUE" = 'serialNumber',
+              componentType: "Type of component" = 'BT'):
+    "Look up production stage for a component."
+    from loguru import logger
+    logger.info(f"Getting component from the DB")
+    component = dd.lookup(project=project, lookupKey=lookupKey, value=[
+        lookupValue], componentType=componentType, returnResults=True)
+    if len(component) == 0:
+        logger.error(
+            "No components that match the criteria were found in the DB")
+        raise LookupError
+    elif len(component) > 1:
+        logger.error(
+            "More than 1 component that match the criteria was found")
+        raise LookupError
+    component = component[lookupValue]
+    return component['currentStage']['code']
+
+
+def set_stage(lookupValue: "Value to look up (must be unique in the DB!)",
           stage: "Production stage to set",
           project: "ATLAS Project" = 'S',
           subProject: "ATLAS Subproject" = "SE",
           lookupKey: "Key that corresponds to VALUE" = 'serialNumber',
           componentType: "Type of component" = 'BT',
           comment: "Reason for production stage change" = ""):
-    "Set or look up production stage for a component."
+    'Set production stage for a component. Ex: didis stage "20USECP9000050" "" componentType="COOLING_PIPE"????'
     logger.info(f"Getting component from the DB")
     component = lookup(project=project, subProject=subProject, lookupKey=lookupKey, value=[
                        lookupValue], componentType=componentType, returnResults=True)
@@ -199,6 +225,8 @@ def stage(lookupValue: "Value to look up (must be unique in the DB!)",
         logger.error(
             f"DB error, is {stage} a valid stage for {componentType}?")
 
+def stage(*args, **kwargs):
+    return set_stage(*args, **kwargs)
 
 def skeleton(test: "Type of test",
              componentType: "Type of component" = "BT",
@@ -442,14 +470,16 @@ def ship(components: "Component codes",
     except Exception as e:
         logger.error(e)
         if len(components) == 1:
-            logger.info("This is probably a DB bug, check if your shipment was created using the web interface.")
+            logger.info(
+                "This is probably a DB bug, check if your shipment was created using the web interface.")
         logger.error("Error while trying to get connection to DB")
         logger.info(
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
+
 def testresult(tid: "Test ID",
-             returnResults: "Return lookup results (useful if not used from CLI)" = False,
-             printJSON: "PrettyPrint the component JSON" = False):
+               returnResults: "Return lookup results (useful if not used from CLI)" = False,
+               printJSON: "PrettyPrint the component JSON" = False):
     "Look up a test result for a given test ID."
     try:
         logger.info(f"Looking up tests TID = {tid}")
@@ -465,10 +495,11 @@ def testresult(tid: "Test ID",
         logger.info(
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
+
 def main():
     parser = argh.ArghParser()
     parser.add_commands([authenticate, register, lookup,
-                        attach, tests, stage,
+                        attach, tests, get_stage, set_stage,
                         skeleton, upload, testruns,
                         testfile, assemble, property,
                         comment, ship, testresult])
